Learn R Programming

inTextSummaryTable (version 3.4.0)

convertSummaryStatisticsTableToFlextable: Convert summary statistics table to flextable

Description

Convert summary statistics table to flextable

Usage

convertSummaryStatisticsTableToFlextable(
  summaryTable,
  colHeaderMerge = TRUE,
  landscape = (style == "presentation"),
  margin = 1,
  rowPadBase = 14.4,
  title = NULL,
  footer = NULL,
  style = "report",
  colorTable = getColorPaletteTable(style = style),
  fontname = switch(style, report = "Times", presentation = "Tahoma"),
  fontsize = switch(style, report = 8, presentation = 10),
  file = NULL,
  pageDim = NULL,
  columnsWidth = NULL
)

Value

flextable object with summary table If summaryTable is a list of summary tables, returns a list of flextable.

Arguments

summaryTable

A summaryTable object.

colHeaderMerge

(flextable output) Logical, if TRUE (FALSE by default) the column header is merged.

landscape

(flextable output) Logical, if TRUE the file is in landscape format.
By default: FALSE if style is 'report' and TRUE if style is 'presentation'.

margin

(flextable output) Margin in the document in inches (1 by default). This is used to specify the width of the table, from: [pageDim[1] - 2 * margin].

rowPadBase

(flextable output) Base padding for row (in points), 14.4 by default (corresponds to 0.2 inches)

title

Character vector with title(s) for the table. Set to NULL (by default) if no title should be included. If multiple are specified, specified for each element of byVar (in order of the levels).

footer

(flextable output) Character vector with footer(s) for the table. Set to NULL (by default) if no footer should be included.

style

(flextable output) String with table style, either 'report' or 'presentation'. This parameter affects the fontsize, font family, color of the text and background, and table dimensions of the table.

colorTable

(flextable output) Named character vector with color for the table background/body/text/line, e.g. created with the getColorPaletteTable function.

fontname

(flextable output) String with font name, by default: 'Times' if style is 'report' and 'Tahoma' if style is 'presentation'.

fontsize

(flextable output) Integer with font size, by default: 8 if style is 'report' and 10 if style is 'presentation'.

file

String with path of the file where the table should be exported. The file should have the extension: '.html'. If NULL, the summary table is not exported but only returned as output. If byVar is specified, each table is exported to a separated file with the suffix: 'file_[i].html' with i the index of the file.

pageDim

Numeric vector of length 2 with page width and height.
Depending on outputType:

  • 'flextable': in inches

  • 'DT': in number of rows in the table.
    Currently only the height is used (e.g. c(NA, 4))

columnsWidth

Column widths of the table, for outputType:

  • 'flextable': the widths can be specified either:

    • in percentage: the sum of the widths should be 1

    • in inch: the sum should be the page width (see getDimPage)

    If the widths are not specified for all columns, the width of the remaining last columns is set such as the width of the total table is the page width.

  • 'DT': see getClinDT

Author

Laure Cougnaud